@@ -1,15 +1,15 @@
-#
+# 
 # This file is part of Config-Model-TkUI
-#
+# 
 # This software is Copyright (c) 2010 by Dominique Dumont.
-#
+# 
 # This is free software, licensed under:
-#
+# 
 #   The GNU Lesser General Public License, Version 2.1, February 1999
-#
+# 
 package Config::Model::Tk::HashEditor ;
 BEGIN {
-  $Config::Model::Tk::HashEditor::VERSION = '1.309';
+  $Config::Model::Tk::HashEditor::VERSION = '1.311';
 }
 
 use strict;
@@ -104,8 +104,15 @@ sub Populate {
     $label_keep_frame -> Label (-text => 'Item:')
       -> pack(-side => 'left', -anchor => 'w') ;
 
-    my $keep_b = $label_keep_frame -> Checkbutton (-variable => \$keep, 
-					    -text => 'keep')
+    # copy selected entry text into item (textvariable) when $keep is set
+    my $keep_cb = sub { 
+	my $sel = $tklist->curselection;
+	$item = $keep && $sel ? $tklist->get($sel) : '' ;
+    };
+	
+    my $keep_b = $label_keep_frame -> Checkbutton ( -variable => \$keep, 
+						    -command => $keep_cb,
+						    -text => 'keep')
       -> pack  (qw/-side right -anchor e/) ;
     $balloon->attach($keep_b, 
 		     -msg => 'keep entry in widget after add, move or copy');
@@ -119,7 +126,7 @@ sub Populate {
 
     # bind both entries to update correctly the state of all buttons
     my $bound_sub = sub { 
-	$cw->update_state(entry => $item , tklist => $tklist->curselection) 
+	$cw->update_state(entry => $item , tklist => $tklist->curselection || 0) 
     };
     $entry -> bind( '<KeyPress>'       , $bound_sub );
     $tklist-> bind( '<<ListboxSelect>>', $bound_sub );
